aboutsummaryrefslogtreecommitdiff
path: root/arch/s390/kernel
diff options
context:
space:
mode:
authorHeiko Carstens <heiko.carstens@de.ibm.com>2015-10-12 13:03:05 +0200
committerMartin Schwidefsky <schwidefsky@de.ibm.com>2015-10-27 09:33:56 +0100
commit975be635d929e3cfdae149d6de055f31a17c92d7 (patch)
tree7364a9fef5295f527145a1bdbfeb6576c9a26659 /arch/s390/kernel
parentdc6e15556a9f21d640a62ae6de3cbfa68ec687a4 (diff)
s390/nmi: fix terminology
According to the architecture registers are validated and not revalidated. So change comments and functions names to match. Signed-off-by: Heiko Carstens <heiko.carstens@de.ibm.com> Signed-off-by: Martin Schwidefsky <schwidefsky@de.ibm.com>
Diffstat (limited to 'arch/s390/kernel')
-rw-r--r--arch/s390/kernel/nmi.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/arch/s390/kernel/nmi.c b/arch/s390/kernel/nmi.c
index 3c69483faa10..b3004f4ac493 100644
--- a/arch/s390/kernel/nmi.c
+++ b/arch/s390/kernel/nmi.c
@@ -101,7 +101,7 @@ EXPORT_SYMBOL_GPL(s390_handle_mcck);
* returns 0 if all registers could be validated
* returns 1 otherwise
*/
-static int notrace s390_revalidate_registers(union mci mci)
+static int notrace s390_validate_registers(union mci mci)
{
int kill_task;
u64 zero;
@@ -137,7 +137,7 @@ static int notrace s390_revalidate_registers(union mci mci)
asm volatile("lfpc 0(%0)" : : "a" (fpt_creg_save_area));
if (!MACHINE_HAS_VX) {
/* Revalidate floating point registers */
asm volatile(
" ld 0,0(%0)\n"
" ld 1,8(%0)\n"
@@ -157,7 +157,7 @@ static int notrace s390_revalidate_registers(union mci mci)
" ld 15,120(%0)\n"
: : "a" (fpt_save_area));
} else {
/* Revalidate vector registers */
union ctlreg0 cr0;
if (!mci.vr) {
@@ -178,7 +178,7 @@ static int notrace s390_revalidate_registers(union mci mci)
&S390_lowcore.vector_save_area) : "1");
__ctl_load(S390_lowcore.cregs_save_area[0], 0, 0);
}
/* Revalidate access registers */
asm volatile(
" lam 0,15,0(%0)"
: : "a" (&S390_lowcore.access_regs_save_area));
@@ -189,7 +189,7 @@ static int notrace s390_revalidate_registers(union mci mci)
*/
kill_task = 1;
}
/* Revalidate control registers */
if (!mci.cr) {
/*
* Control registers have unknown contents.
@@ -202,11 +202,11 @@ static int notrace s390_revalidate_registers(union mci mci)
: : "a" (&S390_lowcore.cregs_save_area));
}
/*
* We don't even try to revalidate the TOD register, since we simply
* can't write something sensible into that register.
*/
/*
* See if we can revalidate the TOD programmable register with its
* old contents (should be zero) otherwise set it to zero.
*/
if (!mci.pr)
@@ -220,7 +220,7 @@ static int notrace s390_revalidate_registers(union mci mci)
" sckpf"
: : "a" (&S390_lowcore.tod_progreg_save_area)
: "0", "cc");
/* Revalidate clock comparator register */
set_clock_comparator(S390_lowcore.clock_comparator);
/* Check if old PSW is valid */
if (!mci.wp)
@@ -302,7 +302,7 @@ void notrace s390_do_machine_check(struct pt_regs *regs)
s390_handle_damage();
}
}
- if (s390_revalidate_registers(mci)) {
+ if (s390_validate_registers(mci)) {
if (umode) {
/*
* Couldn't restore all register contents while in
@@ -137,7 +137,7 @@ static int notrace s390_revalidate_registers(union mci mci)
asm volatile("lfpc 0(%0)" : : "a" (fpt_creg_save_area));
if (!MACHINE_HAS_VX) {
- /* Revalidate floating point registers */
+ /* Validate floating point registers */
asm volatile(
" ld 0,0(%0)\n"
@@ -157,7 +157,7 @@ static int notrace s390_revalidate_registers(union mci mci)
: : "a" (fpt_save_area));
} else {
- /* Revalidate vector registers */
+ /* Validate vector registers */
union ctlreg0 cr0;
if (!mci.vr) {
@@ -178,7 +178,7 @@ static int notrace s390_revalidate_registers(union mci mci)
__ctl_load(S390_lowcore.cregs_save_area[0], 0, 0);
}
- /* Revalidate access registers */
+ /* Validate access registers */
asm volatile(
" lam 0,15,0(%0)"
@@ -189,7 +189,7 @@ static int notrace s390_revalidate_registers(union mci mci)
kill_task = 1;
}
- /* Revalidate control registers */
+ /* Validate control registers */
if (!mci.cr) {
/*
@@ -202,11 +202,11 @@ static int notrace s390_revalidate_registers(union mci mci)
}
/*
- * We don't even try to revalidate the TOD register, since we simply
+ * We don't even try to validate the TOD register, since we simply
* can't write something sensible into that register.
*/
@@ -202,11 +202,11 @@ static int notrace s390_revalidate_registers(union mci mci)
*/
/*
- * See if we can revalidate the TOD programmable register with its
+ * See if we can validate the TOD programmable register with its
* old contents (should be zero) otherwise set it to zero.
*/
@@ -220,7 +220,7 @@ static int notrace s390_revalidate_registers(union mci mci)
: : "a" (&S390_lowcore.tod_progreg_save_area)
: "0", "cc");
- /* Revalidate clock comparator register */
+ /* Validate clock comparator register */
set_clock_comparator(S390_lowcore.clock_comparator);
/* Check if old PSW is valid */